==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/fi.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Hakemistoon \"config\" kirjoittaminen ei onnistu!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Tämän voi yleensä korjata antamalla http-palvelimelle kirjoitusoikeuden asetushakemistoon",
    "See %s" : "Katso %s",
    "Sample configuration detected" : "Esimerkkimääritykset havaittu",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "On havaittu, että esimerkkimäärityksen on kopioitu. Se voi rikkoa asennuksesi, eikä sitä tueta. Lue ohjeet ennen kuin muutat config.php tiedostoa.",
    "%1$s and %2$s" : "%1$s ja %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s ja %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s ja %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s ja %5$s",
    "PHP %s or higher is required." : "PHP %s tai sitä uudempi vaaditaan.",
    "PHP with a version lower than %s is required." : "PHP versiota %s alempi tarvitaan.",
    "%sbit or higher PHP required." : "%s-bit tai korkeampi PHP vaaditaan.",
    "Following databases are supported: %s" : "Seuraavat tietokannat ovat tuettuja: %s",
    "The command line tool %s could not be found" : "Komentorivityökalua %s ei löytynyt",
    "The library %s is not available." : "Kirjastoa %s ei ole käytettävissä.",
    "Following platforms are supported: %s" : "Seuraavat alustat ovat tuettuja: %s",
    "Server version %s or higher is required." : "Palvelinversio %s tai sitä uudempi vaaditaan.",
    "Server version %s or lower is required." : "Palvelinversio %s tai alhaisempi vaaditaan.",
    "Logged in user must be an admin" : "Sisäänkirjautuneen käyttäjän tulee olla ylläpitäjä",
    "Authentication" : "Tunnistautuminen",
    "Unknown filetype" : "Tuntematon tiedostotyyppi",
    "Invalid image" : "Virheellinen kuva",
    "Avatar image is not square" : "Avatar-kuva ei ole neliö",
    "today" : "tänään",
    "tomorrow" : "huomenna",
    "yesterday" : "eilen",
    "_in %n day_::_in %n days_" : ["%n päivän päästä","%n päivän päästä"],
    "_%n day ago_::_%n days ago_" : ["%n päivä sitten","%n päivää sitten"],
    "next month" : "ensi kuussa",
    "last month" : "viime kuussa",
    "_in %n month_::_in %n months_" : ["%n kuukauden päästä","%n kuukauden päästä"],
    "_%n month ago_::_%n months ago_" : ["%n kuukausi sitten","%n kuukautta sitten"],
    "next year" : "ensi vuonna",
    "last year" : "viime vuonna",
    "_in %n year_::_in %n years_" : ["%n vuoden päästä","%n vuoden päästä"],
    "_%n year ago_::_%n years ago_" : ["%n vuosi sitten","%n vuotta sitten"],
    "_in %n hour_::_in %n hours_" : ["%n tunnin päästä","%n tunnin päästä"],
    "_%n hour ago_::_%n hours ago_" : ["%n tunti sitten","%n tuntia sitten"],
    "_in %n minute_::_in %n minutes_" : ["%n minuutin päästä","%n minuutin päästä"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minuutti sitten","%n minuuttia sitten"],
    "in a few seconds" : "muutaman sekunnin päästä",
    "seconds ago" : "sekunteja sitten",
    "File name is a reserved word" : "Tiedoston nimi on varattu sana",
    "File name contains at least one invalid character" : "Tiedoston nimi sisältää ainakin yhden virheellisen merkin",
    "File name is too long" : "Tiedoston nimi on liian pitkä",
    "Dot files are not allowed" : "Pistetiedostot eivät ole sallittuja",
    "Empty filename is not allowed" : "Tiedostonimi ei voi olla tyhjä",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Sovellusta \"%s\" ei voi asentaa, koska appinfo-tiedostoa ei voi loi lukea.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Sovellusta \"%s\" ei voi asentaa, koska se ei ole yhteensopiva tämän palvelinversion kanssa.",
    "__language_name__" : "suomi",
    "This is an automatically sent email, please do not reply." : "Tämä on automaattisesti lähetetty viesti. Älä vastaa tähän viestiin.",
    "Help" : "Ohje",
    "Apps" : "Sovellukset",
    "Settings" : "Asetukset",
    "Log out" : "Kirjaudu ulos",
    "Users" : "Käyttäjät",
    "Unknown user" : "Tuntematon käyttäjä",
    "Basic settings" : "Perusasetukset",
    "Sharing" : "Jakaminen",
    "Security" : "Turvallisuus",
    "Additional settings" : "Lisäasetukset",
    "Personal info" : "Henkilökohtaiset tiedot",
    "Mobile & desktop" : "Mobiili ja työpöytä",
    "%s enter the database username and name." : "%s anna tietokannan käyttäjätunnus ja nimi.",
    "%s enter the database username." : "%s anna tietokannan käyttäjätunnus.",
    "%s enter the database name." : "%s anna tietokannan nimi.",
    "%s you may not use dots in the database name" : "%s et voi käyttää pisteitä tietokannan nimessä",
    "Oracle connection could not be established" : "Oracle-yhteyttä ei voitu muodostaa",
    "Oracle username and/or password not valid" : "Oraclen käyttäjätunnus ja/tai salasana on väärin",
    "PostgreSQL username and/or password not valid" : "PostgreSQL:n käyttäjätunnus ja/tai salasana on väärin",
    "You need to enter details of an existing account." : "Anna olemassa olevan tilin tiedot.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X ei ole tuettu, joten %s ei toimi kunnolla tällä alustalla. Käytä omalla vastuulla!",
    "For the best results, please consider using a GNU/Linux server instead." : "Käytä parhaan lopputuloksen saamiseksi GNU/Linux-palvelinta.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Vaikuttaa siltä, että tämä %s-instanssi toimii 32-bittisessä PHP-ympäristössä ja open_basedir-asetus on määritetty php.ini-tiedostossa. Tämä johtaa ongelmiin yli 4 gigatavun tiedostojen kanssa, eikä siksi ole suositeltavaa.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Poista open_basedir-asetus php.ini-tiedostosta tai vaihda 64-bittiseen PHP:hen.",
    "Set an admin username." : "Aseta ylläpitäjän käyttäjätunnus.",
    "Set an admin password." : "Aseta ylläpitäjän salasana.",
    "Can't create or write into the data directory %s" : "Ei voi luoda tai kirjoittaa data-hakemistoon %s",
    "Invalid Federated Cloud ID" : "Virheellinen federoidun pilven tunniste",
    "Sharing backend %s not found" : "Jakamisen taustaosaa %s ei löytynyt",
    "Sharing backend for %s not found" : "Jakamisen taustaosaa kohteelle %s ei löytynyt",
    "Open »%s«" : "Avaa »%s«",
    "You are not allowed to share %s" : "Oikeutesi eivät riitä kohteen %s jakamiseen.",
    "Expiration date is in the past" : "Vanhenemispäivä on menneisyydessä",
    "%1$s shared »%2$s« with you" : "%1$s jakoi kohteen »%2$s« kanssasi",
    "%1$s shared »%2$s« with you." : "%1$s jakoi kohteen »%2$s« kanssasi.",
    "Click the button below to open it." : "Napsauta alla olevaa painiketta avataksesi sen.",
    "The requested share does not exist anymore" : "Pyydettyä jakoa ei ole enää olemassa",
    "Could not find category \"%s\"" : "Luokkaa \"%s\" ei löytynyt",
    "Sunday" : "sunnuntai",
    "Monday" : "maanantai",
    "Tuesday" : "tiistai",
    "Wednesday" : "keskiviikko",
    "Thursday" : "torstai",
    "Friday" : "perjantai",
    "Saturday" : "lauantai",
    "Sun." : "Su",
    "Mon." : "Ma",
    "Tue." : "Ti",
    "Wed." : "Ke",
    "Thu." : "To",
    "Fri." : "Pe",
    "Sat." : "La",
    "Su" : "Su",
    "Mo" : "Ma",
    "Tu" : "Ti",
    "We" : "Ke",
    "Th" : "To",
    "Fr" : "Pe",
    "Sa" : "La",
    "January" : "tammikuu",
    "February" : "helmikuu",
    "March" : "maaliskuu",
    "April" : "huhtikuu",
    "May" : "toukokuu",
    "June" : "kesäkuu",
    "July" : "heinäkuu",
    "August" : "elokuu",
    "September" : "syyskuu",
    "October" : "lokakuu",
    "November" : "marraskuu",
    "December" : "joulukuu",
    "Jan." : "Tammi",
    "Feb." : "Helmi",
    "Mar." : "Maalis",
    "Apr." : "Huhti",
    "May." : "Touko",
    "Jun." : "Kesä",
    "Jul." : "Heinä",
    "Aug." : "Elo",
    "Sep." : "Syys",
    "Oct." : "Loka",
    "Nov." : "Marras",
    "Dec." : "Joulu",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Vain seuraavat merkit ovat sallittuja käyttäjätunnuksessa: \"a-z\", \"A-Z\", \"0-9\" ja \"_.@-'\"",
    "A valid username must be provided" : "Anna kelvollinen käyttäjätunnus",
    "Username contains whitespace at the beginning or at the end" : "Käyttäjätunnus sisältää tyhjätilaa joko alussa tai lopussa",
    "Username must not consist of dots only" : "Käyttäjänimi ei voi koostua vain pisteistä",
    "A valid password must be provided" : "Anna kelvollinen salasana",
    "The username is already being used" : "Käyttäjätunnus on jo käytössä",
    "Could not create user" : "Ei voitu luoda käyttäjää",
    "User disabled" : "Käyttäjä poistettu käytöstä",
    "Login canceled by app" : "Kirjautuminen peruttiin sovelluksen toimesta",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Sovellusta \"%1$s\" ei voi asentaa, koska seuraavat riippuvuudet eivät täyty: %2$s",
    "a safe home for all your data" : "turvallinen koti kaikille tiedostoillesi",
    "File is currently busy, please try again later" : "Tiedosto on parhaillaan käytössä, yritä myöhemmin uudelleen",
    "Can't read file" : "Tiedostoa ei voi lukea",
    "Application is not enabled" : "Sovellusta ei ole otettu käyttöön",
    "Authentication error" : "Tunnistautumisvirhe",
    "Token expired. Please reload page." : "Valtuutus vanheni. Lataa sivu uudelleen.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Tietokanta-ajureita (sqlite, mysql tai postgresql) ei ole asennettu.",
    "Cannot write into \"config\" directory" : "Hakemistoon \"config\" kirjoittaminen ei onnistu",
    "Cannot write into \"apps\" directory" : "Hakemistoon \"apps\" kirjoittaminen ei onnistu",
    "Cannot create \"data\" directory" : "Hakemiston \"data\" luominen ei onnistu",
    "Setting locale to %s failed" : "Maa-asetuksen %s asettaminen epäonnistui",
    "Please install one of these locales on your system and restart your webserver." : "Asenna ainakin yksi kyseisistä maa-asetuksista järjestelmään ja käynnistä http-palvelin uudelleen.",
    "Please ask your server administrator to install the module." : "Pyydä palvelimen ylläpitäjää asentamaan moduulin.",
    "PHP module %s not installed." : "PHP-moduulia %s ei ole asennettu.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-asetusta \"%s\" ei ole asetettu arvoon \"%s\".",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload on asetettu arvoon \"%s\" odotetun arvon \"0\" sijaan",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Korjaa tämä ongelma asettamalla <code>mbstring.func_overload</code> arvoon <code>0</code> php.ini-tiedostossasi",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Vähintään libxml2 2.7.0 vaaditaan. %s on asennettu.",
    "To fix this issue update your libxml2 version and restart your web server." : "Päivitä libxml2:n versio ja käynnistä http-palvelin uudelleen.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tämä johtuu todennäköisesti välimuistista tai kiihdyttimestä kuten Zend OPcachesta tai eAcceleratorista.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduulit on asennettu, mutta ovatko ne vieläkin listattu puuttuviksi?",
    "Please ask your server administrator to restart the web server." : "Pyydä palvelimen ylläpitäjää käynnistämään web-palvelin uudelleen.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 vaaditaan",
    "Please upgrade your database version" : "Päivitä tietokantasi versio",
    "Your data directory is readable by other users" : "Data-hakemisto on muiden käyttäjien luettavissa",
    "Your data directory must be an absolute path" : "Data-hakemiston tulee olla absoluuttinen polku",
    "Check the value of \"datadirectory\" in your configuration" : "Tarkista \"datadirectory\"-arvo asetuksistasi",
    "Your data directory is invalid" : "Datahakemistosi on virheellinen",
    "Action \"%s\" not supported or implemented." : "Toiminto \"%s\" ei ole tuettu tai sitä ei ole toteutettu.",
    "Could not obtain lock type %d on \"%s\"." : "Lukitustapaa %d ei saatu kohteelle \"%s\".",
    "Storage unauthorized. %s" : "Tallennustila ei ole valtuutettu. %s",
    "Storage incomplete configuration. %s" : "Tallennustilan puutteellinen määritys. %s",
    "Storage connection error. %s" : "Tallennustilan yhteysvirhe. %s",
    "Storage is temporarily not available" : "Tallennustila on tilapäisesti pois käytöstä",
    "Storage connection timeout. %s" : "Tallennustilan yhteyden aikakatkaisu. %s",
    "Create" : "Luo",
    "Change" : "Muuta",
    "Delete" : "Poista",
    "Share" : "Jaa",
    "Unlimited" : "Rajoittamaton",
    "Verifying" : "Vahvistetaan",
    "Verifying …" : "Vahvistetaan…",
    "Verify" : "Vahvista",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Kohteen %s jakaminen epäonnistui, koska tietovarasto ei salli %i tyyppisiä jakoja",
    "Sharing %s failed, because the file does not exist" : "Kohteen %s jakaminen epäonnistui, koska tiedostoa ei ole olemassa",
    "Sharing %s failed, because you can not share with yourself" : "Kohteen %s jakaminen epäonnistui, koska et voi jakaa itsesi kanssa",
    "You need to provide a password to create a public link, only protected links are allowed" : "Anna salasana luodaksesi julkisen linkin. Vain suojatut linkit ovat sallittuja",
    "Sharing %s failed, because sharing with links is not allowed" : "Kohteen %s jakaminen epäonnistui, koska jakaminen linkkejä käyttäen ei ole sallittu",
    "Not allowed to create a federated share with the same user" : "Saman käyttäjän kanssa ei ole sallittua luoda federoitua jakoa",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Vanhenemispäivää ei voi asettaa. Jako ei voi vanhentua myöhemmin kuin %s päivää sen jälkeen kun se on jaettu",
    "Cannot set expiration date. Expiration date is in the past" : "Vanhenemispäivää ei voi asettaa. Vanhenemispäivä on jo mennyt",
    "Sharing failed, because the user %s is the original sharer" : "Jakaminen epäonnistui, koska käyttäjä %s ei ole alkuperäinen jakaja",
    "Sharing %s failed, because resharing is not allowed" : "Kohteen %s jakaminen epäonnistui, koska jakaminen uudelleen ei ole sallittu",
    "Sharing %s failed, because the file could not be found in the file cache" : "Kohteen %s jakaminen epäonnistui, koska tiedostoa ei löytynyt tiedostovälimuistista"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/fi.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Hakemistoon \"config\" kirjoittaminen ei onnistu!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Tämän voi yleensä korjata antamalla http-palvelimelle kirjoitusoikeuden asetushakemistoon",
    "See %s" : "Katso %s",
    "Sample configuration detected" : "Esimerkkimääritykset havaittu",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "On havaittu, että esimerkkimäärityksen on kopioitu. Se voi rikkoa asennuksesi, eikä sitä tueta. Lue ohjeet ennen kuin muutat config.php tiedostoa.",
    "%1$s and %2$s" : "%1$s ja %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s ja %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s ja %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s ja %5$s",
    "PHP %s or higher is required." : "PHP %s tai sitä uudempi vaaditaan.",
    "PHP with a version lower than %s is required." : "PHP versiota %s alempi tarvitaan.",
    "%sbit or higher PHP required." : "%s-bit tai korkeampi PHP vaaditaan.",
    "The following databases are supported: %s" : "Seuraavat tietokannat ovat tuettuja: %s",
    "The command line tool %s could not be found" : "Komentorivityökalua %s ei löytynyt",
    "The library %s is not available." : "Kirjastoa %s ei ole käytettävissä.",
    "The following platforms are supported: %s" : "Seuraavat alustat ovat tuettuja: %s",
    "Server version %s or higher is required." : "Palvelinversio %s tai sitä uudempi vaaditaan.",
    "Server version %s or lower is required." : "Palvelinversio %s tai alhaisempi vaaditaan.",
    "Logged in user must be an admin" : "Sisäänkirjautuneen käyttäjän tulee olla ylläpitäjä",
    "Wiping of device %s has started" : "Laitteen %s tyhjennys aloitettiin",
    "Wiping of device »%s« has started" : "Laitteen »%s« tyhjennys aloitettiin",
    "»%s« started remote wipe" : "»%s« aloitti etätyhjennyksen",
    "Wiping of device %s has finished" : "Laitteen %s tyhjennys valmistui",
    "Wiping of device »%s« has finished" : "Laitteen »%s« tyhjennys valmistui",
    "Remote wipe started" : "Etätyhjennys aloitettiin",
    "A remote wipe was started on device %s" : "Laitteen %s etätyhjennys aloitettiin",
    "Remote wipe finished" : "Etätyhjennys valmistui",
    "The remote wipe on %s has finished" : "Etätyhjennys laitteella %s valmistui",
    "Authentication" : "Tunnistautuminen",
    "Unknown filetype" : "Tuntematon tiedostotyyppi",
    "Invalid image" : "Virheellinen kuva",
    "Avatar image is not square" : "Avatar-kuva ei ole neliö",
    "today" : "tänään",
    "tomorrow" : "huomenna",
    "yesterday" : "eilen",
    "_in %n day_::_in %n days_" : ["%n päivän päästä","%n päivän päästä"],
    "_%n day ago_::_%n days ago_" : ["%n päivä sitten","%n päivää sitten"],
    "next month" : "ensi kuussa",
    "last month" : "viime kuussa",
    "_in %n month_::_in %n months_" : ["%n kuukauden päästä","%n kuukauden päästä"],
    "_%n month ago_::_%n months ago_" : ["%n kuukausi sitten","%n kuukautta sitten"],
    "next year" : "ensi vuonna",
    "last year" : "viime vuonna",
    "_in %n year_::_in %n years_" : ["%n vuoden päästä","%n vuoden päästä"],
    "_%n year ago_::_%n years ago_" : ["%n vuosi sitten","%n vuotta sitten"],
    "_in %n hour_::_in %n hours_" : ["%n tunnin päästä","%n tunnin päästä"],
    "_%n hour ago_::_%n hours ago_" : ["%n tunti sitten","%n tuntia sitten"],
    "_in %n minute_::_in %n minutes_" : ["%n minuutin päästä","%n minuutin päästä"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minuutti sitten","%n minuuttia sitten"],
    "in a few seconds" : "muutaman sekunnin päästä",
    "seconds ago" : "sekunteja sitten",
    "Empty file" : "Tyhjä tiedosto",
    "File name is a reserved word" : "Tiedoston nimi on varattu sana",
    "File name contains at least one invalid character" : "Tiedoston nimi sisältää ainakin yhden virheellisen merkin",
    "File name is too long" : "Tiedoston nimi on liian pitkä",
    "Dot files are not allowed" : "Pistetiedostot eivät ole sallittuja",
    "Empty filename is not allowed" : "Tiedostonimi ei voi olla tyhjä",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Sovellusta \"%s\" ei voi asentaa, koska appinfo-tiedostoa ei voi loi lukea.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Sovellusta \"%s\" ei voi asentaa, koska se ei ole yhteensopiva tämän palvelinversion kanssa.",
    "__language_name__" : "suomi",
    "This is an automatically sent email, please do not reply." : "Tämä on automaattisesti lähetetty viesti. Älä vastaa tähän viestiin.",
    "Help" : "Ohje",
    "Apps" : "Sovellukset",
    "Settings" : "Asetukset",
    "Log out" : "Kirjaudu ulos",
    "Users" : "Käyttäjät",
    "Unknown user" : "Tuntematon käyttäjä",
    "Additional settings" : "Lisäasetukset",
    "%s enter the database username and name." : "%s anna tietokannan käyttäjätunnus ja nimi.",
    "%s enter the database username." : "%s anna tietokannan käyttäjätunnus.",
    "%s enter the database name." : "%s anna tietokannan nimi.",
    "%s you may not use dots in the database name" : "%s et voi käyttää pisteitä tietokannan nimessä",
    "MySQL username and/or password not valid" : "MySQL-käyttäjätunnus ja/tai -salasana on väärin",
    "You need to enter details of an existing account." : "Anna olemassa olevan tilin tiedot.",
    "Oracle connection could not be established" : "Oracle-yhteyttä ei voitu muodostaa",
    "Oracle username and/or password not valid" : "Oraclen käyttäjätunnus ja/tai salasana on väärin",
    "PostgreSQL username and/or password not valid" : "PostgreSQL:n käyttäjätunnus ja/tai salasana on väärin",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X ei ole tuettu, joten %s ei toimi kunnolla tällä alustalla. Käytä omalla vastuulla!",
    "For the best results, please consider using a GNU/Linux server instead." : "Käytä parhaan lopputuloksen saamiseksi GNU/Linux-palvelinta.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Vaikuttaa siltä, että tämä %s-instanssi toimii 32-bittisessä PHP-ympäristössä ja open_basedir-asetus on määritetty php.ini-tiedostossa. Tämä johtaa ongelmiin yli 4 gigatavun tiedostojen kanssa, eikä siksi ole suositeltavaa.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Poista open_basedir-asetus php.ini-tiedostosta tai vaihda 64-bittiseen PHP:hen.",
    "Set an admin username." : "Aseta ylläpitäjän käyttäjätunnus.",
    "Set an admin password." : "Aseta ylläpitäjän salasana.",
    "Can't create or write into the data directory %s" : "Ei voi luoda tai kirjoittaa data-hakemistoon %s",
    "Sharing backend %s not found" : "Jakamisen taustaosaa %s ei löytynyt",
    "Sharing backend for %s not found" : "Jakamisen taustaosaa kohteelle %s ei löytynyt",
    "Open »%s«" : "Avaa »%s«",
    "You are not allowed to share %s" : "Oikeutesi eivät riitä kohteen %s jakamiseen.",
    "Expiration date is in the past" : "Vanhenemispäivä on menneisyydessä",
    "%1$s shared »%2$s« with you" : "%1$s jakoi kohteen »%2$s« kanssasi",
    "%1$s shared »%2$s« with you." : "%1$s jakoi kohteen »%2$s« kanssasi.",
    "Click the button below to open it." : "Napsauta alla olevaa painiketta avataksesi sen.",
    "The requested share does not exist anymore" : "Pyydettyä jakoa ei ole enää olemassa",
    "Could not find category \"%s\"" : "Luokkaa \"%s\" ei löytynyt",
    "Sunday" : "sunnuntai",
    "Monday" : "maanantai",
    "Tuesday" : "tiistai",
    "Wednesday" : "keskiviikko",
    "Thursday" : "torstai",
    "Friday" : "perjantai",
    "Saturday" : "lauantai",
    "Sun." : "Su",
    "Mon." : "Ma",
    "Tue." : "Ti",
    "Wed." : "Ke",
    "Thu." : "To",
    "Fri." : "Pe",
    "Sat." : "La",
    "Su" : "Su",
    "Mo" : "Ma",
    "Tu" : "Ti",
    "We" : "Ke",
    "Th" : "To",
    "Fr" : "Pe",
    "Sa" : "La",
    "January" : "tammikuu",
    "February" : "helmikuu",
    "March" : "maaliskuu",
    "April" : "huhtikuu",
    "May" : "toukokuu",
    "June" : "kesäkuu",
    "July" : "heinäkuu",
    "August" : "elokuu",
    "September" : "syyskuu",
    "October" : "lokakuu",
    "November" : "marraskuu",
    "December" : "joulukuu",
    "Jan." : "Tammi",
    "Feb." : "Helmi",
    "Mar." : "Maalis",
    "Apr." : "Huhti",
    "May." : "Touko",
    "Jun." : "Kesä",
    "Jul." : "Heinä",
    "Aug." : "Elo",
    "Sep." : "Syys",
    "Oct." : "Loka",
    "Nov." : "Marras",
    "Dec." : "Joulu",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Vain seuraavat merkit ovat sallittuja käyttäjätunnuksessa: \"a-z\", \"A-Z\", \"0-9\" ja \"_.@-'\"",
    "A valid username must be provided" : "Anna kelvollinen käyttäjätunnus",
    "Username contains whitespace at the beginning or at the end" : "Käyttäjätunnus sisältää tyhjätilaa joko alussa tai lopussa",
    "Username must not consist of dots only" : "Käyttäjänimi ei voi koostua vain pisteistä",
    "A valid password must be provided" : "Anna kelvollinen salasana",
    "The username is already being used" : "Käyttäjätunnus on jo käytössä",
    "Could not create user" : "Ei voitu luoda käyttäjää",
    "User disabled" : "Käyttäjä poistettu käytöstä",
    "Login canceled by app" : "Kirjautuminen peruttiin sovelluksen toimesta",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Sovellusta \"%1$s\" ei voi asentaa, koska seuraavat riippuvuudet eivät täyty: %2$s",
    "a safe home for all your data" : "turvallinen koti kaikille tiedostoillesi",
    "File is currently busy, please try again later" : "Tiedosto on parhaillaan käytössä, yritä myöhemmin uudelleen",
    "Can't read file" : "Tiedostoa ei voi lukea",
    "Application is not enabled" : "Sovellusta ei ole otettu käyttöön",
    "Authentication error" : "Tunnistautumisvirhe",
    "Token expired. Please reload page." : "Valtuutus vanheni. Lataa sivu uudelleen.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Tietokanta-ajureita (sqlite, mysql tai postgresql) ei ole asennettu.",
    "Cannot write into \"config\" directory" : "Hakemistoon \"config\" kirjoittaminen ei onnistu",
    "Cannot write into \"apps\" directory" : "Hakemistoon \"apps\" kirjoittaminen ei onnistu",
    "Cannot create \"data\" directory" : "Hakemiston \"data\" luominen ei onnistu",
    "Setting locale to %s failed" : "Maa-asetuksen %s asettaminen epäonnistui",
    "Please install one of these locales on your system and restart your webserver." : "Asenna ainakin yksi kyseisistä maa-asetuksista järjestelmään ja käynnistä http-palvelin uudelleen.",
    "PHP module %s not installed." : "PHP-moduulia %s ei ole asennettu.",
    "Please ask your server administrator to install the module." : "Pyydä palvelimen ylläpitäjää asentamaan moduulin.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-asetusta \"%s\" ei ole asetettu arvoon \"%s\".",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload on asetettu arvoon \"%s\" odotetun arvon \"0\" sijaan",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Korjaa tämä ongelma asettamalla <code>mbstring.func_overload</code> arvoon <code>0</code> php.ini-tiedostossasi",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Vähintään libxml2 2.7.0 vaaditaan. %s on asennettu.",
    "To fix this issue update your libxml2 version and restart your web server." : "Päivitä libxml2:n versio ja käynnistä http-palvelin uudelleen.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tämä johtuu todennäköisesti välimuistista tai kiihdyttimestä kuten Zend OPcachesta tai eAcceleratorista.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduulit on asennettu, mutta ovatko ne vieläkin listattu puuttuviksi?",
    "Please ask your server administrator to restart the web server." : "Pyydä palvelimen ylläpitäjää käynnistämään web-palvelin uudelleen.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 vaaditaan",
    "Please upgrade your database version" : "Päivitä tietokantasi versio",
    "Your data directory is readable by other users" : "Data-hakemisto on muiden käyttäjien luettavissa",
    "Your data directory must be an absolute path" : "Data-hakemiston tulee olla absoluuttinen polku",
    "Check the value of \"datadirectory\" in your configuration" : "Tarkista \"datadirectory\"-arvo asetuksistasi",
    "Your data directory is invalid" : "Datahakemistosi on virheellinen",
    "Action \"%s\" not supported or implemented." : "Toiminto \"%s\" ei ole tuettu tai sitä ei ole toteutettu.",
    "Could not obtain lock type %d on \"%s\"." : "Lukitustapaa %d ei saatu kohteelle \"%s\".",
    "Storage unauthorized. %s" : "Tallennustila ei ole valtuutettu. %s",
    "Storage incomplete configuration. %s" : "Tallennustilan puutteellinen määritys. %s",
    "Storage connection error. %s" : "Tallennustilan yhteysvirhe. %s",
    "Storage is temporarily not available" : "Tallennustila on tilapäisesti pois käytöstä",
    "Storage connection timeout. %s" : "Tallennustilan yhteyden aikakatkaisu. %s",
    "Following databases are supported: %s" : "Seuraavat tietokannat ovat tuettuja: %s",
    "Following platforms are supported: %s" : "Seuraavat alustat ovat tuettuja: %s",
    "Basic settings" : "Perusasetukset",
    "Sharing" : "Jakaminen",
    "Security" : "Turvallisuus",
    "Personal info" : "Henkilökohtaiset tiedot",
    "Mobile & desktop" : "Mobiili ja työpöytä",
    "Invalid Federated Cloud ID" : "Virheellinen federoidun pilven tunniste"
},
"nplurals=2; plural=(n != 1);");
